%global  nginx_ver           1.10.1
%global  ngx_small_light_ver 0.9.0
%global  lua_ver             0.10.7
%global  _hardened_build     1
%global  nginx_user          nginx

# gperftools exist only on selected arches
%ifnarch s390 s390x
%global with_gperftools 1
%endif

%global with_aio 1

%if 0%{?fedora} > 22
%global with_mailcap_mimetypes 1
%endif

Name:              nginx-extras
Epoch:             1
Version:           %{nginx_ver}
Release:           1%{?dist}

Summary:           Extra modules for nginx
Group:             System Environment/Daemons
# BSD License (two clause)
# http://www.freebsd.org/copyright/freebsd-license.html
License:           BSD
URL:               http://nginx.org/

Source0:           http://nginx.org/download/nginx-%{nginx_ver}.tar.gz
Source1:           http://nginx.org/download/nginx-%{nginx_ver}.tar.gz.asc

Source2:	   ngx_small_light-%{ngx_small_light_ver}.tar.gz
Source3:	   lua-nginx-module-%{lua_ver}.tar.gz
# removes -Werror in upstream build scripts.  -Werror conflicts with
# -D_FORTIFY_SOURCE=2 causing warnings to turn into errors.
Patch0:            nginx-auto-cc-gcc.patch

%if 0%{?with_gperftools}
BuildRequires:     gperftools-devel
%endif
BuildRequires:     openssl-devel
BuildRequires:     pcre-devel
BuildRequires:     zlib-devel
BuildRequires:     systemd
BuildRequires:     GeoIP-devel
BuildRequires:     gd-devel
BuildRequires:     perl-devel
BuildRequires:     perl-generators
BuildRequires:     perl(ExtUtils::Embed)
BuildRequires:     libxslt-devel

Requires:          nginx = %{epoch}:%{nginx_ver}-%{release}

%description
Extra modules for nginx.

%package -n nginx-mod-http-small-light
Version:	   %{ngx_small_light_ver}
Group:             System Environment/Daemons
Summary:           Dynamic image transformation module for nginx
BuildRequires:     ImageMagick-devel
BuildRequires:     imlib2-devel
BuildRequires:     gd-devel
Requires:          nginx

%description -n nginx-mod-http-small-light
Dynamic image transformation module for nginx. Supports the various
image-processings below.

Resize
Rotate
Sharpen
Unsharpen
Blur
Border
Canvas
Crop
Composition
JPEG Hinting(except GD)
Format convert(e.g. PNG -> JPEG)
Color-space convert(e.g. CMYK -> sRGB)

%package -n nginx-mod-http-lua
Group:             System Environment/Daemons
Version:	   %{lua_ver}
Summary:           Embed the power of Lua into Nginx HTTP Servers.
BuildRequires:     lua-devel
Requires:          nginx

%description -n nginx-mod-http-lua
This module embeds Lua, via the standard Lua 5.1 interpreter and by
leveraging Nginx's subrequests, allows the integration of the powerful
Lua threads (Lua coroutines) into the Nginx event model.

%prep
%setup -q -n nginx-source -c -a 2 -a 3
cd nginx-%{nginx_ver}
%patch0 -p0
cd ../

%build
cd ngx_small_light-%{ngx_small_light_ver}
./setup
MOD1=`pwd`
cd ..
cd lua-nginx-module-%{lua_ver}
MOD2=`pwd`
cd ..
cd nginx-%{nginx_ver}
# nginx does not utilize a standard configure script.  It has its own
# and the standard configure options cause the nginx configure script
# to error out.  This is is also the reason for the DESTDIR environment
# variable.
export DESTDIR=%{buildroot}
./configure \
    --prefix=%{_datadir}/nginx \
    --sbin-path=%{_sbindir}/nginx \
    --modules-path=%{_libdir}/nginx/modules \
    --conf-path=%{_sysconfdir}/nginx/nginx.conf \
    --error-log-path=%{_localstatedir}/log/nginx/error.log \
    --http-log-path=%{_localstatedir}/log/nginx/access.log \
    --http-client-body-temp-path=%{_localstatedir}/lib/nginx/tmp/client_body \
    --http-proxy-temp-path=%{_localstatedir}/lib/nginx/tmp/proxy \
    --http-fastcgi-temp-path=%{_localstatedir}/lib/nginx/tmp/fastcgi \
    --http-uwsgi-temp-path=%{_localstatedir}/lib/nginx/tmp/uwsgi \
    --http-scgi-temp-path=%{_localstatedir}/lib/nginx/tmp/scgi \
    --pid-path=/run/nginx.pid \
    --lock-path=/run/lock/subsys/nginx \
    --user=%{nginx_user} \
    --group=%{nginx_user} \
%if 0%{?with_aio}
    --with-file-aio \
%endif
    --with-ipv6 \
    --with-http_ssl_module \
    --with-http_v2_module \
    --with-http_realip_module \
    --with-http_addition_module \
    --with-http_xslt_module=dynamic \
    --with-http_image_filter_module=dynamic \
    --with-http_geoip_module=dynamic \
    --with-http_sub_module \
    --with-http_dav_module \
    --with-http_flv_module \
    --with-http_mp4_module \
    --with-http_gunzip_module \
    --with-http_gzip_static_module \
    --with-http_random_index_module \
    --with-http_secure_link_module \
    --with-http_degradation_module \
    --with-http_slice_module \
    --with-http_stub_status_module \
    --with-http_perl_module=dynamic \
    --with-mail=dynamic \
    --with-mail_ssl_module \
    --with-pcre \
    --with-pcre-jit \
    --with-stream=dynamic \
    --with-stream_ssl_module \
%if 0%{?with_gperftools}
    --with-google_perftools_module \
%endif
    --add-dynamic-module=$MOD1 \
    --add-dynamic-module=$MOD2 \
    --with-debug \
    --with-cc-opt="%{optflags} $(pcre-config --cflags)" \
    --with-ld-opt="$RPM_LD_FLAGS -Wl,-E" # so the perl module finds its symbols \

#make %{?_smp_mflags}
make -f objs/Makefile modules

%install
mkdir -p %{buildroot} INSTALLDIRS=vendor

install -p -d -m 0755 %{buildroot}%{_datadir}/nginx/modules
install -p -d -m 0755 %{buildroot}%{_libdir}/nginx/modules
cd nginx-%{nginx_ver}
install -m 0755 objs/ngx_http_lua_module.so %{buildroot}%{_libdir}/nginx/modules/
install -m 0755 objs/ngx_http_small_light_module.so %{buildroot}%{_libdir}/nginx/modules/

echo 'load_module "%{_libdir}/nginx/modules/ngx_http_small_light_module.so";' \
    > %{buildroot}%{_datadir}/nginx/modules/mod-http-small-light-module.conf
echo 'load_module "%{_libdir}/nginx/modules/ngx_http_lua_module.so";' \
    > %{buildroot}%{_datadir}/nginx/modules/mod-http-lua.conf

%post -n nginx-mod-http-small-light
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi

%post -n nginx-mod-http-lua
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi

%files -n nginx-mod-http-small-light
%license ngx_small_light-%{ngx_small_light_ver}/COPYING
%doc ngx_small_light-%{ngx_small_light_ver}/README.md ngx_small_light-%{ngx_small_light_ver}/ChangeLog
%{_datadir}/nginx/modules/mod-http-small-light-module.conf
%{_libdir}/nginx/modules/ngx_http_small_light_module.so

%files -n nginx-mod-http-lua
%license nginx-%{nginx_ver}/LICENSE
%doc lua-nginx-module-%{lua_ver}/README.markdown lua-nginx-module-%{lua_ver}/doc/HttpLuaModule.wiki
%{_datadir}/nginx/modules/mod-http-lua.conf
%{_libdir}/nginx/modules/ngx_http_lua_module.so

%changelog
* Sun Nov 13 2016 Josko Plazonic <plazonic@princeton.edu>
- based on EPEL nginx make it into a module only build; we still
  need all of base components due to silly way nginx builds modules
